==> com.liferay.site.my.sites.web-5.0.11.jar: META-INF/resources/js/SiteDropdownDefaultEventHandler.es.js <==
Liferay.Loader.define("my-sites-web@5.0.11/js/SiteDropdownDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var SiteDropdownDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(SiteDropdownDefaultEventHandler, _DefaultEventHandler);

    function SiteDropdownDefaultEventHandler() {
      _classCallCheck(this, SiteDropdownDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(SiteDropdownDefaultEventHandler).apply(this, arguments));
    }

    _createClass(SiteDropdownDefaultEventHandler, [{
      key: "joinSite",
      value: function joinSite(itemData) {
        this._send(itemData.joinSiteURL);
      }
    }, {
      key: "leaveSite",
      value: function leaveSite(itemData) {
        this._send(itemData.leaveSiteURL);
      }
    }, {
      key: "_send",
      value: function _send(url) {
        submitForm(document.hrefFm, url);
      }
    }]);

    return SiteDropdownDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  var _default = SiteDropdownDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=SiteDropdownDefaultEventHandler.es.js.map
});
//# sourceMappingURL=SiteDropdownDefaultEventHandler.es.js.map

==> com.liferay.site.my.sites.web-5.0.12.jar: META-INF/resources/js/SiteDropdownDefaultEventHandler.es.js <==
Liferay.Loader.define("my-sites-web@5.0.12/js/SiteDropdownDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var SiteDropdownDefaultEventHandler = /*#__PURE__*/function (_DefaultEventHandler) {
    _inherits(SiteDropdownDefaultEventHandler, _DefaultEventHandler);

    function SiteDropdownDefaultEventHandler() {
      _classCallCheck(this, SiteDropdownDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(SiteDropdownDefaultEventHandler).apply(this, arguments));
    }

    _createClass(SiteDropdownDefaultEventHandler, [{
      key: "joinSite",
      value: function joinSite(itemData) {
        this._send(itemData.joinSiteURL);
      }
    }, {
      key: "leaveSite",
      value: function leaveSite(itemData) {
        this._send(itemData.leaveSiteURL);
      }
    }, {
      key: "_send",
      value: function _send(url) {
        submitForm(document.hrefFm, url);
      }
    }]);

    return SiteDropdownDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  var _default = SiteDropdownDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=SiteDropdownDefaultEventHandler.es.js.map
});
//# sourceMappingURL=SiteDropdownDefaultEventHandler.es.js.map
